@@ -15,10 +15,8 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c(":="))
 #'   relations in the style of an edge list, or a list of data frames
 #'   similar to `alters.df`.
 #' @template ID.vars
-#' @param ego_design A [`list`] of arguments to
-#'   [srvyr::as_survey_design()] specifying the sampling design for
-#'   the egos. If formulas, they can refer to columns of
-#'   `egos.df`. `NULL` means that no design is set.
+#' @templateVar ego_design_name ego_design
+#' @template ego_design
 #' @param alter_design A [`list`] of arguments specifying nomination
 #'   information. Currently, the following elements are supported:
 #'   \describe{\item{\code{"max"}}{Maximum number of alters that an
@@ -49,19 +47,25 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c(":="))
 #'   nominated. See the argument above for currently implemented
 #'   settings.
 #' @keywords ego-centered network analysis
-#' @seealso [as_tibble()] for extracting ego, alter, and alter--alter tables, as [`tibble`]s or as `srvyr`'s [`tbl_svy`] surveys.
+#' @seealso [tibble::as_tibble()] for extracting ego, alter, and alter--alter tables, as [`tibble::tibble`]s or as `srvyr`'s [`srvyr::tbl_svy`] surveys.
 #' @examples 
 #' data("egos32")
 #' data("alters32")
 #' data("aaties32") 
 #' 
-#' egor(alters32, 
-#'      egos32, 
-#'      aaties32,
-#'      ID.vars = list(ego = ".EGOID", 
-#'                     alter = ".ALTID", 
-#'                     source = ".SRCID",
-#'                     target =  ".TGTID"))
+#' e <- egor(alters32,
+#'           egos32,
+#'           aaties32,
+#'           ID.vars = list(ego = ".EGOID",
+#'                          alter = ".ALTID",
+#'                          source = ".SRCID",
+#'                          target =  ".TGTID"),
+#'           ego_design = alist(strata = sex))
+#'
+#' e
+#'
+#' ego_design(e)
+#'
 #' @export
 egor <- function(alters,
                     egos = NULL,
@@ -197,18 +201,13 @@ egor <- function(alters,
   if (!all(c(aaties[[IDVARS$ego]] %in% egos[[IDVARS$ego]])))
     stop("There is at least one ego ID in the `alter-alter` data with no corresponding entry in the `alter` data.",
          call. = FALSE)
-  
-  alter_aatie_ids_consistent <- 
-    purrr::map_lgl(egos[[IDVARS$ego]],
-                   function(x){
-                     sym_ego_id <- rlang::sym(IDVARS$ego)
-                     alter <- filter(alters, !!sym_ego_id == x)
-                     aatie <- filter(aaties, !!sym_ego_id == x)
-                     
-                     all(c(aatie[[IDVARS$source]], 
-                           aatie[[IDVARS$target]]) %in% alter[[IDVARS$alter]])
-                   })
-  
+
+  altID_by_egoID <- split(alters[[IDVARS$alter]] %||% logical(0), factor(alters[[IDVARS$ego]], egos[[IDVARS$ego]]))
+  aaID_by_egoID <- map2(split(aaties[[IDVARS$source]], factor(aaties[[IDVARS$ego]], egos[[IDVARS$ego]])),
+                        split(aaties[[IDVARS$target]], factor(aaties[[IDVARS$ego]], egos[[IDVARS$ego]])),
+                        c)
+  alter_aatie_ids_consistent <- purrr::map2_lgl(altID_by_egoID, aaID_by_egoID, function(a, aa) all(aa %in% a))
+
   if(!all(alter_aatie_ids_consistent))
     stop("There is at least one alter referenced in the `alter-alter` data that is not listed in the `alter` data. Errors were found for egos: ", 
          paste(egos[[IDVARS$ego]][!alter_aatie_ids_consistent], collapse = " "),
@@ -238,14 +237,32 @@ summary.egor <- function(object, ...) {
   # Network count
   nc <- nrow(object$ego)
   
-  # Min, Max  & Average netsize
-  min_nts <- min(table(object$alter$.egoID))
-  max_nts <- max(table(object$alter$.egoID))
-  avg_nts <- mean(table(object$alter$.egoID))
+  alter_counts <- 
+    object$alter |>
+    summarise(.netsize = n(), .by = .egoID)
   
+  # add zero counts for egos with no alters
+  alter_counts <-
+    bind_rows(
+      alter_counts,
+      object |>
+        activate(ego) |>
+        select(.egoID) |>
+        filter(!.egoID %in% alter_counts$.egoID) |>
+        mutate(.netsize = 0) |> 
+        as_tibble()
+    ) |>
+    arrange(.egoID)
+  
+  # Min, Max  & Average netsize
+  min_nts <- min(alter_counts$.netsize)
+  max_nts <- max(alter_counts$.netsize)
+  avg_nts <- mean(alter_counts$.netsize)
+
   if(has_ego_design(object)) {
-    object$ego$variables$avg_nts <- avg_nts
-    avg_nts <- survey::svymean(~avg_nts, object$ego)
+    object$ego$variables <- 
+      left_join(object$ego$variables, alter_counts, by = ".egoID")
+    avg_nts <- survey::svymean(~.netsize, object$ego) |> unname()
   }
   
   # Total number of alters
@@ -260,7 +277,7 @@ summary.egor <- function(object, ...) {
       options(egor.results_with_design = TRUE)
       
       dens <- ego_density(object)
-      dens <- survey::svymean(~density, dens)
+      dens <- survey::svymean(~density, dens, na.rm = TRUE)
       
       options(egor.results_with_design = errwd_value)
       
@@ -286,6 +303,11 @@ summary.egor <- function(object, ...) {
   
   cat("Alter survey design:\n")
   cat("  Maximum nominations:", attr(object, "alter_design")$max,"\n")
+  
+  invisible(tibble(
+    stat = c("Networks", "Alters", "min. Netsize", "Average Netsize", "max. Netsize", "Average Density"),
+    value = c(nc, alts_count, min_nts, avg_nts, max_nts, dens) |> unname()
+  ))
 }
 
 #' @rdname summary.egor
