@@ -23,6 +23,7 @@ plot_ego_graphs <- function(x,
                             edge_zoom = 3,
                             font_size = 1,
                             include_ego = FALSE,
+                            ego_attrs = NULL,
                             ...) {
   require_igraph(paste(sQuote("egor"),"plotting ego graphs"))
   opar <- par(no.readonly = TRUE)
@@ -55,6 +56,7 @@ plot_ego_graphs <- function(x,
         edge_zoom = edge_zoom,
         font_size = font_size,
         include_ego = include_ego,
+        ego_attrs = ego_attrs,
         ...
       )
     }
@@ -80,13 +82,21 @@ plot_one_ego_graph <- function(x,
                                edge_zoom = 3,
                                font_size = 1,
                                include_ego = FALSE,
+                               ego_attrs = NULL,
                                layout = NULL,
                                ...) {
   x <- 
     slice.egor(activate(x, "ego"), ego_no)
   
+  if (include_ego) {
+    if (vertex_label_var %in% names(x$ego)) {
+      ego_attrs <- c(ego_attrs, vertex_label_var)
+    }
+  }
+  
   gr <- as_igraph(x, 
                   include.ego = include_ego, 
+                  ego.attrs = ego_attrs,
                   ego.alter.weights = c(ego_alter_edge_width_var,
                                         ego_alter_edge_color_var)
                   )[[1]]
@@ -113,7 +123,7 @@ plot_one_ego_graph <- function(x,
   # Vertex Size
   if (!is.null(vertex_size_var)) {
     vertex.size <-
-      as.numeric(as.factor(igraph::get.vertex.attribute(gr, vertex_size_var)))
+      as.numeric(as.factor(igraph::vertex_attr(gr, vertex_size_var)))
     vertex.size[is.na(vertex.size)] <- 0.1
     vertex.size <- vertex.size * vertex_zoom + .1
   } else {
@@ -124,12 +134,12 @@ plot_one_ego_graph <- function(x,
   # Vertex Color
   if (!is.null(vertex_color_var)) {
     vertex.color <-
-      igraph::get.vertex.attribute(gr, vertex_color_var)
+      igraph::vertex_attr(gr, vertex_color_var)
     #vertex.color[is.na(vertex.color)] <- 0
     vertex.color <- factor(vertex.color)
     colors_ <- egor_col_pal(vertex_color_palette,
                             length(levels(
-                              factor(igraph::get.vertex.attribute(gr,
+                              factor(igraph::vertex_attr(gr,
                                                                   vertex_color_var))
                             )))
     clrs <- colors_[vertex.color]
@@ -142,7 +152,7 @@ plot_one_ego_graph <- function(x,
   # Edge Width
   if (!is.null(edge_width_var)) {
     edge.width <-
-      igraph::get.edge.attribute(gr, edge_width_var) * edge_zoom
+      igraph::edge_attr(gr, edge_width_var) * edge_zoom
     #edge.width[is.na(edge.width)] <- 0
   } else {
     edge.width <-
@@ -151,12 +161,12 @@ plot_one_ego_graph <- function(x,
   
   # Edge Color
   if (!is.null(edge_color_var)) {
-    edge.color <- igraph::get.edge.attribute(gr, edge_color_var)
+    edge.color <- igraph::edge_attr(gr, edge_color_var)
     #edge.color[is.na(edge.color)] <- 0
     edge.color <- as.numeric(factor(edge.color))
     e_colors <- egor_col_pal(edge_color_palette,
                              length(levels(
-                               factor(igraph::get.edge.attribute(gr,
+                               factor(igraph::edge_attr(gr,
                                                                  edge_color_var))
                              )))
   } else {
@@ -166,7 +176,10 @@ plot_one_ego_graph <- function(x,
     # Label
   if (!is.null(vertex_label_var)) {
     vertex.label <-
-      igraph::get.vertex.attribute(gr, vertex_label_var)
+      igraph::vertex_attr(gr, vertex_label_var)
+    if(include_ego && is.na(vertex.label[length(vertex.label)])) {
+      vertex.label[length(vertex.label)] <- "ego"
+    }
     vertex.label[is.na(vertex.label)] <- 0
   } else {
     vertex.label <- ""
@@ -178,18 +191,27 @@ plot_one_ego_graph <- function(x,
   
   if (is.null(layout)) {
     layout_ <-
-      igraph::layout.fruchterman.reingold(gr, weights = edge.width)
+      igraph::layout_with_fr(gr, weights = edge.width)
   } else {
     layout_ <- layout
   }
-  
-  set.seed(1337)
-  
+
   if(include_ego) {
     # Set curvature of ego-alter ties to zero
     # igraph::E(gr)$curved[is.na(igraph::E(gr)$curved)] <- 0
     # Set ego-alter weights to a dummy value
-    igraph::E(gr)$weight[is.na(igraph::E(gr)$weight)] <- min(igraph::E(gr)$weight, na.rm = TRUE)
+    if (any(!is.na(igraph::E(gr)$weight))) {
+      # Set to min of other weights, so scale of weights is comparable
+      igraph::E(gr)$weight[is.na(igraph::E(gr)$weight)] <- min(igraph::E(gr)$weight, na.rm = TRUE)
+    } else {
+      # no other weights in the graph, so just set a hardwired dummy value
+      # if there is no weight variable at all, E(gr)$weight will be NULL rather than a vector,
+      # so the syntax igraph::E(gr)$weight[is.na(igraph::E(gr)$weight)] will fail. Since all weights
+      # are NULL or NA at this point, set them all to 1. This will change missing aatie weights to 1,
+      # which may not be desirable, but overwriting missing aatie weights is also the behavior of the
+      # code above when there is at least one nonmissing aatie weight
+      igraph::E(gr)$weight <- 1
+    }
   }
   
   igraph::plot.igraph(
@@ -227,7 +249,7 @@ plot_one_ego_graph <- function(x,
   # Legend
   
   if (!is.null(vertex_color_var)) {
-    color_var <- igraph::get.vertex.attribute(gr, vertex_color_var)
+    color_var <- igraph::vertex_attr(gr, vertex_color_var)
     #color_var[is.na(color_var)] <- 0
     title_ <-
       ifelse(vertex_color_legend_label == "",
